@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::Logging; # git description: v0.39-55-g6bec8da
+package Task::Kensho::Logging; # git description: v0.40-20-gbbb2f5f
 # ABSTRACT: A Glimpse at an Enlightened Perl: Logging
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::Logging - A Glimpse at an Enlightened Perl: Logging
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -68,6 +68,10 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head2 L<Task::Kensho::Logging>: Logging
 
+=head3 L<Log::Any>
+
+Bringing loggers and listeners together.
+
 =head3 L<Log::Contextual>
 
 Log::Contextual is a simple interface to extensible logging.  It is bundled with a really basic logger, Log::Contextual::SimpleLogger.
@@ -106,7 +110,7 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
+Bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
@@ -117,7 +121,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Olaf Alders Shawn Sorichetti Dan Book Rachel Kelly Chris Nehren Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Dan Book Mohammad S Anwar Olaf Alders Chris Nehren Rachel Kelly Shawn Sorichetti Rick Leir Tina Müller
 
 =over 4
 
@@ -131,11 +135,19 @@ Leo Lapworth <leo@cuckoo.org>
 
 =item *
 
+Dan Book <grinnz@grinnz.com>
+
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
-Shawn Sorichetti <shawn@coloredblocks.com>
+Chris Nehren <apeiron@cpan.org>
 
 =item *
 
@@ -147,12 +159,16 @@ Rachel Kelly <rkellyalso@gmail.com>
 
 =item *
 
-Chris Nehren <apeiron@cpan.org>
+Shawn Sorichetti <shawn@coloredblocks.com>
 
 =item *
 
 Rick Leir <rleir@leirtech.com>
 
+=item *
+
+Tina Müller <cpan2@tinita.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
